#!/bin/bash

#
# Tries to automatically determine architecture and linux distribution 
# and calls IIFCopy with corresponding paths
#
# Institute for Signal Processing, University of Luebeck, Germany
# Florian Mueller, Nov. 2011, mueller@isip.uni-luebeck.de
#
# Version 1.0
#

BINARYNAME="IIFCopy"

# get path of script
SCRIPTDIR="$( cd "$( dirname "$0" )" && pwd )"

# determine architecture
if [[ $(uname -a) = *x86_64* ]]
then
    archi="x86_64"
else
    archi="i386"
fi

# determine distribution
if [[ $(uname -a) = *ubuntu* ]]
then
    distri="ubuntu"
elif [[ $(uname -a) = *Ubuntu* ]]
then
    distri="ubuntu"
elif [[ $(uname -a) = *gentoo* ]]
then
    distri="gentoo"
else
    echo "Unsupported linux distribution: $distri"
    exit
fi
echo "Recognized distribution:  $distri"

echo -e "\n+ + + + + + + + + +\n     IIFCopy\n+ + + + + + + + + +\n"

LIB_PATH="${SCRIPTDIR}/${distri}_${archi}/libs"
if [[ $LD_LIBRARY_PATH != *$LIB_PATH* ]]
then
    echo -e "Adding path for shared libries: $LIB_PATH"
    LD_LIBRARY_PATH="$LIB_PATH:$LD_LIBRARY_PATH"
    export LD_LIBRARY_PATH 
    echo -e "LD_LIBRARY_PATH is now: $LD_LIBRARY_PATH"
fi

BIN_FILE="${SCRIPTDIR}/bin/${distri}_${archi}/$BINARYNAME"

if [ ! -x $BIN_FILE ]
then
    echo "Correcting user permission for executing $BIN_FILE"
    chmod +x $BIN_FILE
fi

echo "Starting $BIN_FILE"
$BIN_FILE $@

